/**
 * Copyright (c) 2015 Camil Staps <info@camilstaps.nl>
 * See the LICENSE file for copying permission.
 */

package com.camilstaps.shop;

import java.io.File;

/**
 * An Article in the webshop
 * @author Camil Staps, s4498062
 */
public class Article extends DatabaseItem {

    /**
     * Basic data about the article
     */
    private final String name;
    private String description;
    private final Category category;
    private File multimedia;
    private final float price;
    
    /**
     * The owner who added the article
     */
    private final User owner;

    /**
     * Straightforwardly creating a new article
     * @param user
     * @param name
     * @param category
     * @param price
     */
    public Article(User user, String name, Category category, float price) {
        this.owner = user;
        this.name = name;
        this.category = category;
        this.price = price;
    }
    
    public User getOwner() {
        return owner;
    }
    
    public String getName() {
        return name;
    }
    
    public String getDescription() {
        return description;
    }
    
    public Category getCategory() {
        return category;
    }
    
    public File getMultimedia() {
        return multimedia;
    }
    
    public float getPrice() {
        return price;
    }

    /**
     * Set a new description
     * @param description
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * Set multimedia
     * @param multimedia
     */
    public void setMultimedia(File multimedia) {
        this.multimedia = multimedia;
    }
    
    @Override
    public String toString() {
        return name + " (" + category.getName() + "): " + Float.toString(price);
    }

}